/**
 * Copyright (c) 2021, WSO2 Inc. (http://www.wso2.com). All Rights Reserved.
 *
 * This software is the property of WSO2 Inc. and its suppliers, if any.
 * Dissemination of any information or reproduction of any material contained
 * herein in any form is strictly forbidden, unless permitted by WSO2 expressly.
 * You may not alter or remove any copyright or other notice from copies of this content."
 */

import { Config } from "../../../../features/core/configs";
import {
    BrandingPreferenceColorsInterface,
    BrandingPreferenceImagesInterface,
    BrandingPreferenceOrganizationDetailsInterface
} from "../models";

export class BrandingPreferenceMeta {

    /**
     * Private constructor to avoid object instantiation from outside
     * the class.
     *
     * @hideconstructor
     */
    private constructor() { }

    /**
     * Get Branding Preference fallback values.
     *
     * @return {Partial<BrandingPreferenceInterface>}
     */
    public static getBrandingPreferenceFallbacks(): {
        images: {
            favicon: BrandingPreferenceImagesInterface[ "favicon" ]
            logo: {
                imgURL: BrandingPreferenceImagesInterface[ "logo" ][ "imgURL" ]
            }
        },
        organizationDetails: Partial<BrandingPreferenceOrganizationDetailsInterface>
        } {

        return {
            images: {
                favicon: {
                    imgURL: Config.getDeploymentConfig().extensions?.defaultBrandedLoginScreenFavicon as string
                },
                logo: {
                    imgURL: Config.getDeploymentConfig().extensions?.defaultBrandedLoginScreenLogo as string
                }
            },
            organizationDetails: {
                copyrightText: (Config.getDeploymentConfig().extensions?.defaultBrandedLoginScreenCopyright as string)
                    .replace("${copyright}", "\u00A9")
                    .replace("${year}", String(new Date().getFullYear()))
            }
        };
    }
    
    public static getThemeSkeleton = (colors: BrandingPreferenceColorsInterface): string => `:root {
    --primaryColor: ${ colors.primary };
    --backgroundColor: #f5f6f6;;
}

/*-----------------------------
        Page Background
        
 Use a simple background color
  if primary color is defined
------------------------------*/

/* Default Page */
.login-portal.layout {
    background: var(--backgroundColor);
}

/* Default Page with Blurred Patch */
.login-portal.layout .page-wrapper {
    background: var(--backgroundColor);
}

/* Error, Success Pages */
.login-portal.layout .page-wrapper.success-page, .login-portal.layout .page-wrapper.error-page {
    background: var(--backgroundColor);
}

/*-----------------------------
        Buttons
------------------------------*/

/* Buttons */
.ui.primary.button {
    background: var(--primaryColor);
}

/*-----------------------------
        Login Box
------------------------------*/

/* Login Box Links */
.login-portal.layout .clickable-link {
    color: var(--primaryColor);
}

/*-----------------------------
     Login Screen Footer
------------------------------*/

.login-portal.layout .footer .ui.text.menu .item:not(.no-hover):hover {
    color: var(--primaryColor);
}

/*-----------------------------
        Anchor Tags
------------------------------*/

/* Anchor Tags */
a {
    color: var(--primaryColor);
}

a:hover {
    color: var(--primaryColor);
    filter: brightness(0.85);
}`;
}
